package net.locusworks.s3sync;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.ApplicationArguments;
import org.springframework.boot.ApplicationRunner;
import org.springframework.boot.autoconfigure.SpringBootApplication;
import org.springframework.boot.builder.SpringApplicationBuilder;
import org.springframework.context.annotation.ComponentScan;
import org.springframework.scheduling.annotation.EnableScheduling;
import org.springframework.stereotype.Component;
import net.locusworks.logger.ApplicationLogger;
import net.locusworks.logger.ApplicationLoggerFactory;
import net.locusworks.s3sync.client.S3Client;


@SpringBootApplication(scanBasePackages= {"net.locusworks.s3sync"})
@ComponentScan("net.locusworks.s3sync")
@Component
@EnableScheduling
public class S3SyncLauncher implements ApplicationRunner {
  
  @Autowired
  private S3Client client;
  
  public static void main(String[] args) {
    new SpringApplicationBuilder(S3SyncLauncher.class).headless(false).run(args);
  }
  
  @Override
  public void run(ApplicationArguments args) throws Exception {
    
    ApplicationLogger logger = ApplicationLoggerFactory.getLogger(S3SyncLauncher.class);
    
    if (System.getenv("AWS_ACCESS_KEY_ID") == null) {
      logger.error("AWS_ACCESS_KEY_ID is not set in environment variables");
      System.exit(-1);
    }
    
    if (System.getenv("AWS_SECRET_ACCESS_KEY") == null) {
      logger.error("AWS_SECRET_ACCESS_KEY is not set in environment variables");
      System.exit(-1);
    }
    
    logger.info("Starting S3 Sync");
    
    try {
      client.syncFolder();
    } catch (Exception | Error e) {
      logger.error(e);
      System.exit(-1);
    } finally {
      client.close();
    }
  }
}
