package net.locusworks.s3sync.client;

import java.io.IOException;
import java.nio.file.Files;
import java.nio.file.Path;
import java.util.Date;
import org.apache.commons.codec.digest.DigestUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import net.locusworks.s3sync.database.entities.FileInfo;
import net.locusworks.s3sync.database.repos.FileInfoRepository;
import net.locusworks.logger.ApplicationLogger;
import net.locusworks.logger.ApplicationLoggerFactory;


@Service
public class FileManager {

  private ApplicationLogger logger = ApplicationLoggerFactory.getLogger(FileManager.class);
  
  @Autowired
  private FileInfoRepository fileInfoRepo;

  public static final String S3SYNC_DB_FILE = "s3sync.mv.db";

  public FileInfo addEntry(Path file, String hash, boolean uploaded) {
    return addEntry(new FileInfo(null, file.getFileName().toString(), file.getParent().toString(), hash, new Date(), uploaded));
  }

  public FileInfo addEntry(FileInfo fd) {
    logger.debug("Saving file: " + fd);
    if (fd.getUploadDate() == null) fd.setUploadDate(new Date());
    return fileInfoRepo.save(fd);
  }

  public FileInfo getFileDetail(Path file, String relativePath) throws IOException {
    String sha1 = DigestUtils.sha1Hex(Files.newInputStream(file));
    
    FileInfo fi = fileInfoRepo.findByFileHash(sha1);
    
    if (fi == null) {
      fi = new FileInfo();
      fi.setFileHash(sha1);
      fi.setFilePath(relativePath);
      fi.setFileName(file.getFileName().toString());
      fi.setUploaded(false);
    }
    
    return fi;
  }

}
