package net.locusworks.s3sync.conf;

import java.io.IOException;
import java.nio.file.Files;
import java.nio.file.Path;
import java.nio.file.Paths;
import java.util.Properties;
import javax.annotation.PostConstruct;
import org.springframework.stereotype.Component;
import net.locusworks.logger.LogLevel;

@Component
public class ConfigurationManager {
  
  private static final String CONF_FILE= "s3.properties";
  private Properties conf;
  
  @PostConstruct
  private void init() {
    try {
      Properties defaultProps = PropertiesManager.loadConfiguration(ConfigurationManager.class, CONF_FILE);
      Path confFile = Paths.get(CONF_FILE);
      
      if (Files.notExists(confFile)) {
        PropertiesManager.saveConfiguration(defaultProps, confFile, "AWS S3 Configuration");
        conf = defaultProps;
      } else {
        conf = PropertiesManager.loadConfiguration(confFile);
        PropertiesManager.addConfiguration(conf, defaultProps);
        PropertiesManager.removeConfiguration(conf, defaultProps);
        PropertiesManager.saveConfiguration(conf, confFile, "AWS S3 Configuration");
      }
      
    } catch (IOException e) {
      throw new RuntimeException(e);
    }
  }
  
  public TransferType getTransferType() {
    return TransferType.getEnum(conf.getProperty("transferType"));
  }
  
  public boolean deleteLocal() {
    return Boolean.getBoolean(conf.getProperty("deleteLocalFiles"));
  }
  
  public String getRegion() {
    return conf.getProperty("region");
  }
  
  public String getBucketName() {
    return conf.getProperty("bucketName");
  }
  
  public String getRemoteFolder() {
    return conf.getProperty("remoteFolder");
  }
  
  public Path getLocalFolder() {
    return Paths.get(conf.getProperty("localFolder"));
  }
  
  public String getUser() {
    return conf.getProperty("user");
  }
  
  public String getIdentity() {
    return conf.getProperty("identity");
  }
  
  public String getHost() {
    return conf.getProperty("host");
  }
  
  public Integer getPort() {
    return Integer.valueOf(conf.getProperty("port"));
  }
  
  public LogLevel getLogLevel() {
    return LogLevel.getEnum(conf.getProperty("logLevel"));
  }
  
}
